@@ -157,7 +157,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -173,30 +173,30 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_events
-import aws_cdk.aws_kms
-import aws_cdk.aws_sns
-import constructs
+import aws_cdk.aws_events as _aws_cdk_aws_events_ceddda9d
+import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
+import aws_cdk.aws_sns as _aws_cdk_aws_sns_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class EventbridgeToSns(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-eventbridge-sns.EventbridgeToSns",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+        event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+        existing_topic_obj: typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic] = None,
+        topic_props: typing.Optional[typing.Union[_aws_cdk_aws_sns_ceddda9d.TopicProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -214,21 +214,7 @@ class EventbridgeToSns(
         :summary: Constructs a new instance of the EventbridgeToSns class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-                topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ae837bca1b6fb3f1872dc439ed6193b4a79c7eccc2534070ee97df52fe9ad88d)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventbridgeToSnsProps(
@@ -246,23 +232,23 @@ class EventbridgeToSns(
 
     @builtins.property
     @jsii.member(jsii_name="eventsRule")
-    def events_rule(self) -> aws_cdk.aws_events.Rule:
-        return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
+    def events_rule(self) -> _aws_cdk_aws_events_ceddda9d.Rule:
+        return typing.cast(_aws_cdk_aws_events_ceddda9d.Rule, jsii.get(self, "eventsRule"))
 
     @builtins.property
     @jsii.member(jsii_name="snsTopic")
-    def sns_topic(self) -> aws_cdk.aws_sns.Topic:
-        return typing.cast(aws_cdk.aws_sns.Topic, jsii.get(self, "snsTopic"))
+    def sns_topic(self) -> _aws_cdk_aws_sns_ceddda9d.Topic:
+        return typing.cast(_aws_cdk_aws_sns_ceddda9d.Topic, jsii.get(self, "snsTopic"))
 
     @builtins.property
     @jsii.member(jsii_name="encryptionKey")
-    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], jsii.get(self, "encryptionKey"))
+    def encryption_key(self) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key], jsii.get(self, "encryptionKey"))
 
     @builtins.property
     @jsii.member(jsii_name="eventBus")
-    def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
-        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
+    def event_bus(self) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus], jsii.get(self, "eventBus"))
 
 
 @jsii.data_type(
@@ -283,14 +269,14 @@ class EventbridgeToSnsProps:
     def __init__(
         self,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+        event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+        existing_topic_obj: typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic] = None,
+        topic_props: typing.Optional[typing.Union[_aws_cdk_aws_sns_ceddda9d.TopicProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
@@ -303,27 +289,15 @@ class EventbridgeToSnsProps:
         :param topic_props: User provided props to override the default props for the SNS Topic. Default: - Default props are used
         '''
         if isinstance(event_rule_props, dict):
-            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+            event_rule_props = _aws_cdk_aws_events_ceddda9d.RuleProps(**event_rule_props)
         if isinstance(encryption_key_props, dict):
-            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
+            encryption_key_props = _aws_cdk_aws_kms_ceddda9d.KeyProps(**encryption_key_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
+            event_bus_props = _aws_cdk_aws_events_ceddda9d.EventBusProps(**event_bus_props)
         if isinstance(topic_props, dict):
-            topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
+            topic_props = _aws_cdk_aws_sns_ceddda9d.TopicProps(**topic_props)
         if __debug__:
-            def stub(
-                *,
-                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-                topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__cd3a4fbe328ce3e78ad0dd66198b27fe5366d91c3b7fb76b43b7f099e751d219)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
             check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
             check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
@@ -332,7 +306,7 @@ class EventbridgeToSnsProps:
             check_type(argname="argument existing_event_bus_interface", value=existing_event_bus_interface, expected_type=type_hints["existing_event_bus_interface"])
             check_type(argname="argument existing_topic_obj", value=existing_topic_obj, expected_type=type_hints["existing_topic_obj"])
             check_type(argname="argument topic_props", value=topic_props, expected_type=type_hints["topic_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "event_rule_props": event_rule_props,
         }
         if enable_encryption_with_customer_managed_key is not None:
@@ -351,14 +325,14 @@ class EventbridgeToSnsProps:
             self._values["topic_props"] = topic_props
 
     @builtins.property
-    def event_rule_props(self) -> aws_cdk.aws_events.RuleProps:
+    def event_rule_props(self) -> _aws_cdk_aws_events_ceddda9d.RuleProps:
         '''User provided eventRuleProps to override the defaults.
 
         :default: - None
         '''
         result = self._values.get("event_rule_props")
         assert result is not None, "Required property 'event_rule_props' is missing"
-        return typing.cast(aws_cdk.aws_events.RuleProps, result)
+        return typing.cast(_aws_cdk_aws_events_ceddda9d.RuleProps, result)
 
     @builtins.property
     def enable_encryption_with_customer_managed_key(
@@ -374,60 +348,64 @@ class EventbridgeToSnsProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+    def encryption_key(self) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key]:
         '''An optional, imported encryption key to encrypt the SNS topic with.
 
         :default: - None.
         '''
         result = self._values.get("encryption_key")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key], result)
 
     @builtins.property
-    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+    def encryption_key_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.KeyProps]:
         '''Optional user provided properties to override the default properties for the KMS encryption key used to  encrypt the SNS topic with.
 
         :default: - None
         '''
         result = self._values.get("encryption_key_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.KeyProps], result)
 
     @builtins.property
-    def event_bus_props(self) -> typing.Optional[aws_cdk.aws_events.EventBusProps]:
+    def event_bus_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBusProps]:
         '''A new custom EventBus is created with provided props.
 
         :default: - None
         '''
         result = self._values.get("event_bus_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_events.EventBusProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBusProps], result)
 
     @builtins.property
     def existing_event_bus_interface(
         self,
-    ) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
+    ) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus]:
         '''Existing instance of a custom EventBus.
 
         :default: - None
         '''
         result = self._values.get("existing_event_bus_interface")
-        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus], result)
 
     @builtins.property
-    def existing_topic_obj(self) -> typing.Optional[aws_cdk.aws_sns.Topic]:
+    def existing_topic_obj(self) -> typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic]:
         '''Existing instance of SNS Topic object, providing both this and topicProps will cause an error..
 
         :default: - Default props are used
         '''
         result = self._values.get("existing_topic_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.Topic], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic], result)
 
     @builtins.property
-    def topic_props(self) -> typing.Optional[aws_cdk.aws_sns.TopicProps]:
+    def topic_props(self) -> typing.Optional[_aws_cdk_aws_sns_ceddda9d.TopicProps]:
         '''User provided props to override the default props for the SNS Topic.
 
         :default: - Default props are used
         '''
         result = self._values.get("topic_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.TopicProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sns_ceddda9d.TopicProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -447,3 +425,33 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__ae837bca1b6fb3f1872dc439ed6193b4a79c7eccc2534070ee97df52fe9ad88d(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
+    enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+    existing_topic_obj: typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic] = None,
+    topic_props: typing.Optional[typing.Union[_aws_cdk_aws_sns_ceddda9d.TopicProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cd3a4fbe328ce3e78ad0dd66198b27fe5366d91c3b7fb76b43b7f099e751d219(
+    *,
+    event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
+    enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+    existing_topic_obj: typing.Optional[_aws_cdk_aws_sns_ceddda9d.Topic] = None,
+    topic_props: typing.Optional[typing.Union[_aws_cdk_aws_sns_ceddda9d.TopicProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
